@@ -104,6 +104,10 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
         data['usergroups'] = [data_usergroup['_id']]
         cls.data_host = cls.backend.post("host", data)
 
+        # Add hostgroup
+        data = {'name': 'allmyhosts', '_realm': cls.realm_all, 'hosts': [cls.data_host['_id']]}
+        cls.data_hostgroup = cls.backend.post("hostgroup", data)
+
         # add service ping
         data = json.loads(open('cfg/service_srv001_ping.json').read())
         data['host'] = cls.data_host['_id']
@@ -113,9 +117,15 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
         data['usergroups'] = [data_usergroup['_id']]
         cls.data_srv_ping = cls.backend.post("service", data)
 
-        # Add hostgroup
-        data = {'name': 'allmyhosts', '_realm': cls.realm_all, 'hosts': [cls.data_host['_id']]}
-        cls.backend.post("hostgroup", data)
+        # add service pong
+        data = json.loads(open('cfg/service_srv001_pong.json').read())
+        data['host'] = cls.data_host['_id']
+        data['check_command'] = data_cmd_ping['_id']
+        data['_realm'] = cls.realm_all
+        data['users'] = [data_user_jeronimo['_id']]
+        data['usergroups'] = [data_usergroup['_id']]
+        data['hostgroups'] = [cls.data_hostgroup['_id']]
+        cls.data_srv_pong = cls.backend.post("service", data)
 
         # add service http
         data = json.loads(open('cfg/service_srv001_http.json').read())
@@ -221,35 +231,37 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
 
     def test_contacts(self):
         reference = [
+            # the default admin user has notifications disabled
             {
                 u'definition_order': 50,
-                u'service_notifications_enabled': True,
-                u'can_submit_commands': False,
+                u'service_notifications_enabled': False,
+                u'can_submit_commands': True,
                 u'can_update_livestate': True,
                 'contact_name': u'admin',
                 'service_notification_commands': '',
                 u'service_notification_options': u'w,u,c,r,f,s',
-                u'definition_order': 50,
                 u'address1': u'',
                 u'address2': u'',
                 u'address3': u'',
                 u'address4': u'',
                 u'address5': u'',
                 u'address6': u'',
-                u'is_admin': False,
+                u'is_admin': True,
                 u'password': self.objects['contacts'][0]['password'],
                 u'pager': u'',
                 u'imported_from': u'alignak-backend',
                 u'notificationways': u'',
                 u'host_notification_period': u'24x7',
-                u'host_notifications_enabled': True,
+                u'host_notifications_enabled': False,
                 'host_notification_commands': '',
                 u'service_notification_period': u'24x7',
                 u'min_business_impact': 0,
                 u'email': u'',
                 u'alias': u'Administrator',
-                u'host_notification_options': u'd,u,r,f,s'
+                u'host_notification_options': u'd,u,r,f,s',
+                u'skill_level': 2
             },
+            # the test created user has default notifications (eg. enabled)
             {
                 u'definition_order': 50,
                 u'service_notifications_enabled': True,
@@ -258,7 +270,6 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 'contact_name': u'jeronimo',
                 'service_notification_commands': '',
                 u'service_notification_options': u'w,u,c,r,f,s',
-                u'definition_order': 50,
                 u'address1': u'',
                 u'address2': u'',
                 u'address3': u'',
@@ -277,14 +288,15 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 u'min_business_impact': 0,
                 u'email': u'',
                 u'alias': u'',
-                u'host_notification_options': u'd,u,r,f,s'
+                u'host_notification_options': u'd,u,r,f,s',
+                u'skill_level': 0
             }
         ]
         self.assertItemsEqual(reference, self.objects['contacts'])
         for cont in self.objects['contacts']:
             for key, value in cont.iteritems():
                 # problem in alignak because not defined
-                if key not in ['can_update_livestate']:
+                if key not in ['can_update_livestate', 'skill_level']:
                     self.assertTrue(Contact.properties[key])
 
     def test_timeperiods(self):
@@ -382,11 +394,12 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 u'icon_image_alt': u'',
                 u'business_impact_modulations': u'',
                 u'retry_interval': 0,
-                u'reactionner_tag': u'',
                 u'parents': '',
                 u'action_url': u'',
                 u'notes_url': u'',
                 u'snapshot_enabled': False,
+                'snapshot_period': u'Never',
+                'maintenance_period': u'Never',
                 u'low_flap_threshold': 25,
                 u'process_perf_data': True,
                 u'icon_image': u'',
@@ -431,8 +444,10 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 u'check_command': u'ping',
                 u'checkmodulations': u'',
                 u'notification_options': u'd,x,r,f,s',
+                'notification_period': u'24x7',
                 u'labels': u'',
-                # u'poller_tag': u'',
+                u'poller_tag': 'None',
+                u'reactionner_tag': 'None',
                 u'obsess_over_host': False,
                 u'high_flap_threshold': 50,
                 u'check_interval': 5,
@@ -516,7 +531,7 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
         self.maxDiff = None
         reference = [
             {
-                'hostgroup_name': u'',
+                'hostgroup_name': '',
                 u'active_checks_enabled': True,
                 u'icon_image_alt': u'',
                 u'business_impact_modulations': u'',
@@ -526,12 +541,15 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 u'action_url': u'',
                 u'is_volatile': False,
                 u'snapshot_enabled': False,
-                u'low_flap_threshold': -1,
+                u'low_flap_threshold': 25,
                 u'process_perf_data': True,
                 u'icon_image': u'',
                 u'snapshot_interval': 5,
+                'snapshot_period': u'Never',
+                'maintenance_period': u'Never',
                 u'default_value': u'',
-                u'business_rule_service_notification_options': u'',
+                u'business_rule_service_notification_options': u'w,u,c,r,f,s',
+                u'business_rule_output_template': u'',
                 u'display_name': u'',
                 u'notification_interval': 60,
                 u'trending_policies': u'',
@@ -541,91 +559,25 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 u'business_rule_downtime_as_ack': False,
                 u'stalking_options': u'',
                 u'event_handler_enabled': False,
-                u'event_handler': u'',
+                u'event_handler': '',
                 u'macromodulations': u'',
                 u'initial_state': 'u',
                 u'first_notification_delay': 0,
                 u'flap_detection_enabled': True,
-                u'business_rule_host_notification_options': u'',
+                u'business_rule_host_notification_options': u'd,u,r,f,s',
                 u'passive_checks_enabled': True,
                 u'host_dependency_enabled': True,
                 u'labels': u'',
                 u'icon_set': u'',
                 u'definition_order': 50,
                 u'parallelize_check': True,
-                u'snapshot_criteria': u'w,c,u,x',
+                u'snapshot_criteria': u'w,c,x',
                 u'notifications_enabled': True,
                 u'aggregation': u'',
                 u'business_rule_smart_notifications': False,
                 'host_name': u'srv001',
-                u'reactionner_tag': u'',
-                'service_description': u'ping',
-                u'imported_from': u'alignak-backend',
-                u'service_dependencies': '',
-                u'time_to_orphanage': 300,
-                u'trigger_name': u'',
-                u'trigger_broker_raise_enabled': False,
-                u'custom_views': u'',
-                u'check_command': u'ping',
-                u'notification_options': u'w,u,c,r,f,s,x',
-                u'notes_url': u'',
-                'merge_host_contacts': False,
-                u'high_flap_threshold': -1,
-                u'check_interval': 5,
-                u'business_impact': 2,
-                u'max_check_attempts': 1,
-                u'notes': u'',
-                u'freshness_threshold': 0,
-                u'check_freshness': False,
-                u'freshness_state': u'o',
-                u'contacts': u'jeronimo',
-                u'contact_groups': u'admins',
-                u'escalations': u''
-            },
-            {
-                'hostgroup_name': u'',
-                u'active_checks_enabled': True,
-                u'icon_image_alt': u'',
-                u'business_impact_modulations': u'',
-                u'retry_interval': 0,
-                u'checkmodulations': u'',
-                u'obsess_over_service': False,
-                u'action_url': u'',
-                u'is_volatile': False,
-                u'snapshot_enabled': False,
-                u'low_flap_threshold': -1,
-                u'process_perf_data': True,
-                u'icon_image': u'',
-                u'snapshot_interval': 5,
-                u'default_value': u'',
-                u'business_rule_service_notification_options': u'',
-                u'display_name': u'',
-                u'notification_interval': 60,
-                u'trending_policies': u'',
-                u'failure_prediction_enabled': False,
-                u'flap_detection_options': u'o,w,c,u,x',
-                u'resultmodulations': u'',
-                u'business_rule_downtime_as_ack': False,
-                u'stalking_options': u'',
-                u'event_handler_enabled': False,
-                u'event_handler': u'',
-                u'macromodulations': u'',
-                u'initial_state': 'u',
-                u'first_notification_delay': 0,
-                u'flap_detection_enabled': True,
-                u'business_rule_host_notification_options': u'',
-                u'passive_checks_enabled': True,
-                u'host_dependency_enabled': True,
-                u'labels': u'',
-                u'icon_set': u'',
-                u'definition_order': 50,
-                u'parallelize_check': True,
-                u'snapshot_criteria': u'w,c,u,x',
-                u'notifications_enabled': True,
-                u'aggregation': u'',
-                u'business_rule_smart_notifications': False,
-                'host_name': u'srv001',
-                u'reactionner_tag': u'',
+                u'poller_tag': 'None',
+                u'reactionner_tag': 'None',
                 'service_description': u'http toto.com',
                 u'imported_from': u'alignak-backend',
                 u'service_dependencies': '',
@@ -635,23 +587,167 @@ class TestArbiterLoadConfiguration(unittest2.TestCase):
                 u'custom_views': u'',
                 u'check_command': u'check_http',
                 u'notification_options': u'w,u,c,r,f,s,x',
+                'notification_period': u'24x7',
                 u'notes_url': u'',
                 'merge_host_contacts': False,
-                u'high_flap_threshold': -1,
+                u'high_flap_threshold': 50,
                 u'check_interval': 5,
                 u'business_impact': 2,
                 u'max_check_attempts': 1,
                 u'notes': u'',
                 u'freshness_threshold': 0,
                 u'check_freshness': False,
-                u'freshness_state': u'o',
+                u'freshness_state': u'x',
                 u'contacts': u'jeronimo',
                 u'contact_groups': u'admins',
-                u'escalations': u''
-            }
+            },
+            {
+                'hostgroup_name': '',
+                u'active_checks_enabled': True,
+                u'icon_image_alt': u'',
+                u'business_impact_modulations': u'',
+                u'retry_interval': 0,
+                u'checkmodulations': u'',
+                u'obsess_over_service': False,
+                u'action_url': u'',
+                u'is_volatile': False,
+                u'snapshot_enabled': False,
+                u'low_flap_threshold': 25,
+                u'process_perf_data': True,
+                u'icon_image': u'',
+                u'snapshot_interval': 5,
+                'snapshot_period': u'Never',
+                'maintenance_period': u'Never',
+                u'default_value': u'',
+                u'business_rule_service_notification_options': u'w,u,c,r,f,s',
+                u'business_rule_output_template': u'',
+                u'display_name': u'',
+                u'notification_interval': 60,
+                u'trending_policies': u'',
+                u'failure_prediction_enabled': False,
+                u'flap_detection_options': u'o,w,c,u,x',
+                u'resultmodulations': u'',
+                u'business_rule_downtime_as_ack': False,
+                u'stalking_options': u'',
+                u'event_handler_enabled': False,
+                u'event_handler': '',
+                u'macromodulations': u'',
+                u'initial_state': 'u',
+                u'first_notification_delay': 0,
+                u'flap_detection_enabled': True,
+                u'business_rule_host_notification_options': u'd,u,r,f,s',
+                u'passive_checks_enabled': True,
+                u'host_dependency_enabled': True,
+                u'labels': u'',
+                u'icon_set': u'',
+                u'definition_order': 50,
+                u'parallelize_check': True,
+                u'snapshot_criteria': u'w,c,x',
+                u'notifications_enabled': True,
+                u'aggregation': u'',
+                u'business_rule_smart_notifications': False,
+                'host_name': u'srv001',
+                u'poller_tag': 'None',
+                u'reactionner_tag': 'None',
+                'service_description': u'ping',
+                u'imported_from': u'alignak-backend',
+                u'service_dependencies': '',
+                u'time_to_orphanage': 300,
+                u'trigger_name': u'',
+                u'trigger_broker_raise_enabled': False,
+                u'custom_views': u'',
+                u'check_command': u'ping',
+                u'notification_options': u'w,u,c,r,f,s,x',
+                'notification_period': u'24x7',
+                u'notes_url': u'',
+                'merge_host_contacts': False,
+                u'high_flap_threshold': 50,
+                u'check_interval': 5,
+                u'business_impact': 2,
+                u'max_check_attempts': 1,
+                u'notes': u'',
+                u'freshness_threshold': 0,
+                u'check_freshness': False,
+                u'freshness_state': u'x',
+                u'contacts': u'jeronimo',
+                u'contact_groups': u'admins',
+            },
+            {
+                'hostgroup_name': u'allmyhosts',
+                u'active_checks_enabled': True,
+                u'icon_image_alt': u'',
+                u'business_impact_modulations': u'',
+                u'retry_interval': 0,
+                u'checkmodulations': u'',
+                u'obsess_over_service': False,
+                u'action_url': u'',
+                u'is_volatile': False,
+                u'snapshot_enabled': False,
+                u'low_flap_threshold': 25,
+                u'process_perf_data': True,
+                u'icon_image': u'',
+                u'snapshot_interval': 5,
+                'snapshot_period': u'Never',
+                'maintenance_period': u'Never',
+                u'default_value': u'',
+                u'business_rule_service_notification_options': u'w,u,c,r,f,s',
+                u'business_rule_output_template': u'',
+                u'display_name': u'',
+                u'notification_interval': 60,
+                u'trending_policies': u'',
+                u'failure_prediction_enabled': False,
+                u'flap_detection_options': u'o,w,c,u,x',
+                u'resultmodulations': u'',
+                u'business_rule_downtime_as_ack': False,
+                u'stalking_options': u'',
+                u'event_handler_enabled': False,
+                u'event_handler': '',
+                u'macromodulations': u'',
+                u'initial_state': 'u',
+                u'first_notification_delay': 0,
+                u'flap_detection_enabled': True,
+                u'business_rule_host_notification_options': u'd,u,r,f,s',
+                u'passive_checks_enabled': True,
+                u'host_dependency_enabled': True,
+                u'labels': u'',
+                u'icon_set': u'',
+                u'definition_order': 50,
+                u'parallelize_check': True,
+                u'snapshot_criteria': u'w,c,x',
+                u'notifications_enabled': True,
+                u'aggregation': u'',
+                u'business_rule_smart_notifications': False,
+                'host_name': u'srv001',
+                u'poller_tag': 'None',
+                u'reactionner_tag': 'None',
+                'service_description': u'pong',
+                u'imported_from': u'alignak-backend',
+                u'service_dependencies': '',
+                u'time_to_orphanage': 300,
+                u'trigger_name': u'',
+                u'trigger_broker_raise_enabled': False,
+                u'custom_views': u'',
+                u'check_command': u'ping',
+                u'notification_options': u'w,u,c,r,f,s,x',
+                'notification_period': u'24x7',
+                u'notes_url': u'',
+                'merge_host_contacts': False,
+                u'high_flap_threshold': 50,
+                u'check_interval': 5,
+                u'business_impact': 2,
+                u'max_check_attempts': 1,
+                u'notes': u'',
+                u'freshness_threshold': 0,
+                u'check_freshness': False,
+                u'freshness_state': u'x',
+                u'contacts': u'jeronimo',
+                u'contact_groups': u'admins',
+            },
         ]
-        self.assertEqual(len(self.objects['services']), 2)
-        self.assertEqual(reference, self.objects['services'])
+        self.assertEqual(len(self.objects['services']), 3)
+        sorted_reference = sorted(reference, key=lambda k: k["service_description"])
+        sorted_list = sorted(self.objects['services'], key=lambda k: k["service_description"])
+        self.assertEqual(sorted_reference, sorted_list)
         for serv in self.objects['services']:
             for key, value in serv.iteritems():
                 if not key.startswith('ls_'):
